## Software Architecture

This module was implemented using the following technologies:

* Java version 7
* Camunda BPMN model API

## Camunda BPMN Model API
The Camunda BPMN model API is a Java library for parsing, creating and editing BPMN 2.0 XML files. This library was the base for the API proposed at this work. It was chosen because it offers several features to BPMN manipulation that include:

**Fluent builder API**: an API to build BPMN models


    BpmnModelInstance modelInstance = Bpmn.createExecutableProcess("processId")
      .startEvent()
      .userTask()
      .endEvent()
      .done();
      
**Validation**: a feature to validate a BPMN model against the BPMN 2.0 specification.


    BpmnModelInstance modelInstance = [...]
    Bpmn.validateModel(modelInstance);


**Find elements inside the model**


    ModelElementInstance elementInstance = modelInstance.getModelElementById("start");
    //find element instance by ID
    
    ModelElementType taskType = modelInstance.getModel().getType(Task.class);
    Collection<ModelElementInstance> elementInstances = modelInstance.getModelElementsByType(taskType);
    //find all elements of the type task

**Save the BPMN model**

    // create BPMN model
    BpmnModelInstance modelInstance = [...]

    // convert to string
    String xmlString = Bpmn.convertToString(modelInstance);

    // write to output stream
    OutputStream outputStream = new OutputStream(...);
    Bpmn.writeModelToStream(outputStream, modelInstance);

     // write to file
     File file = new File(...);
     Bpmn.writeModelToFile(file, modelInstance);